@@ -1,9 +1,20 @@
 import getpass
+import logging
 import re
 
 import requests
 from halo import Halo
 
+from secure_ec2.src.constants import LAUNCH_TEMPLATE_SUFFIX, MODULE_NAME
+
+
+def get_logger() -> logging.Logger:
+    logger = logging.getLogger(__name__)
+    fh = logging.FileHandler("debug.log")
+    fh.setLevel(logging.DEBUG)
+    logger.addHandler(fh)
+    return logger
+
 
 def get_connection_port(os_type: str) -> int:
     """Get default connection port per the OS type"""
@@ -21,7 +32,7 @@ def get_username() -> str:
 
 def get_ip_address() -> str:
     """Get the public IP address of the computer"""
-    with Halo(text="Getting IP address", spinner="dots"):
+    with Halo(text="Getting IP address\r\n", spinner="dots"):
         ip_address = requests.get("http://checkip.amazonaws.com").text.rstrip()
         return ip_address
 
@@ -35,3 +46,9 @@ def get_os_regex(os_type: str) -> str:
     else:
         os_regex = "Windows_Server-2016-English-Nano-Base-2017.10.13"
     return os_regex
+
+
+def get_launch_template_name(os_type: str) -> str:
+    """Build the launch template name by concatenating the username and suffix"""
+    local_username = get_username()
+    return f"{local_username}-{MODULE_NAME}-{os_type.lower()}-{LAUNCH_TEMPLATE_SUFFIX}"
